summaryrefslogtreecommitdiff
path: root/jstests/change_streams
diff options
context:
space:
mode:
authorArun Banala <arun.banala@mongodb.com>2022-04-29 12:56:44 +0100
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-05-23 07:52:57 +0000
commit9d559b3ad8942ade301b41284dee9e6b8c8f098c (patch)
tree2942842824443d062be972c637219e02136ac93c /jstests/change_streams
parentfb4724113317c2279e340047b3a1cd8d6c72fb36 (diff)
downloadmongo-9d559b3ad8942ade301b41284dee9e6b8c8f098c.tar.gz
SERVER-65909 Make oplog and change stream formats of {op: "n"} events consistent
Diffstat (limited to 'jstests/change_streams')
-rw-r--r--jstests/change_streams/projection_fakes_internal_event.js5
1 files changed, 3 insertions, 2 deletions
diff --git a/jstests/change_streams/projection_fakes_internal_event.js b/jstests/change_streams/projection_fakes_internal_event.js
index 77bbbedf358..c9d44151539 100644
--- a/jstests/change_streams/projection_fakes_internal_event.js
+++ b/jstests/change_streams/projection_fakes_internal_event.js
@@ -121,8 +121,9 @@ function assertChangeStreamBehaviour(projection, expectedEvents, expectedErrorCo
csCursor.close();
}
-// Test that a projection which fakes a 'kNewShardDetected' event is swallowed but has no effect.
-let testProjection = {operationType: "kNewShardDetected"};
+// Test that a projection which fakes a 'migrateChunkToNewShard' event is swallowed but has no
+// effect.
+let testProjection = {operationType: "migrateChunkToNewShard"};
assertChangeStreamBehaviour(testProjection, []);
// Test that a projection which fakes an event on config.shards with a non-string operationType is